<?php

namespace Lean\Api\Form;

use CSSLSJ\ExamenFga\Api\{Lib};
use Picea\Ui\Method\{FormContextInterface};
use Ulmus\Entity\EntityInterface;

class Delete implements \Picea\Ui\Method\FormInterface {

    public function __construct(
        public EntityInterface $entity,
    ) {}

    public function getEntity() : EntityInterface
    {
        return $this->entity;
    }

    public function initialize(FormContextInterface $context) : void {}

    public function validate(FormContextInterface $context) : bool
    {
        if ( ! $this->entity->isLoaded() ) {
            $context->pushMessage(Lib\Message::generateError(
                $this->lang('lean.api.form.delete.error.entity')
            ));
        }

        return $context->valid();
    }

    public function execute(FormContextInterface $context) : void
    {
        try {
            if ( $this->getEntity()::repository()->destroy($this->getEntity()) ) {
                $context->pushMessage(Lib\Message::generateSuccess(
                    $this->lang('lean.api.form.delete.success.save')
                ));
            }
            else {
                throw new \InvalidArgumentException($this->lang('lean.api.form.delete.error.save'));
            }
        }
        catch(\Throwable $ex) {
            throw new \ErrorException($this->lang('lean.api.form.delete.error.pdo', [ 'error' => $ex->getMessage() ]));
        }
    }
}
